# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - EventAggregatorSummary Action

    @copyright: 2008, 2009 by Paul Boddie <paul@boddie.org.uk>
    @copyright: 2000-2004 Juergen Hermann <jh@web.de>,
                2005-2008 MoinMoin:ThomasWaldmann.
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

from MoinMoin import config
import EventAggregatorSupport

Dependencies = ['pages']

# Action function.

def execute(pagename, request):

    """
    For the given 'pagename' and 'request', write an iCalendar summary of the
    event data found in the categories specified via the "category" request
    parameter, using the "start" and "end" parameters (if specified). Multiple
    "category" parameters can be specified.
    """

    category_names = request.form.get("category", [])

    if request.form.has_key("start"):
        calendar_start = EventAggregatorSupport.getMonth(request.form["start"][0])
    else:
        calendar_start = None

    if request.form.has_key("end"):
        calendar_end = EventAggregatorSupport.getMonth(request.form["end"][0])
    else:
        calendar_end = None

    events, shown_events, all_shown_events, earliest, latest = \
        EventAggregatorSupport.getEvents(request, category_names, calendar_start, calendar_end)

    # Output iCalendar data...

    request.emit_http_headers(["Content-Type: text/calendar; charset=%s" % config.charset])

    request.write("BEGIN:VCALENDAR\r\n")
    request.write("PRODID:-//MoinMoin//EventAggregatorSummary\r\n")
    request.write("VERSION:2.0\r\n")

    for event_page, event_details in all_shown_events:

        # Get a pretty version of the page name.

        pretty_pagename = EventAggregatorSupport.getPrettyPageName(event_page)

        # Output the event details.

        request.write("BEGIN:VEVENT\r\n")
        request.write("SUMMARY:%s\r\n" % pretty_pagename)
        request.write("UID:%s\r\n" % request.getQualifiedURL(event_page.url(request)))
        request.write("URL:%s\r\n" % request.getQualifiedURL(event_page.url(request)))
        request.write("DTSTART;VALUE=DATE:%04d%02d%02d\r\n" % event_details["start"])
        request.write("DTEND;VALUE=DATE:%04d%02d%02d\r\n" % EventAggregatorSupport.nextdate(event_details["end"]))
        if event_details.has_key("topics"):
            request.write("CATEGORIES:%s\r\n" % ",".join(event_details["topics"]))
        request.write("END:VEVENT\r\n")

    request.write("END:VCALENDAR\r\n")

# vim: tabstop=4 expandtab shiftwidth=4
